summaryrefslogtreecommitdiff
path: root/examples/fxload.c
diff options
context:
space:
mode:
authorhjelmn <Nathan Hjelm hjelmn@cs.unm.edu>2013-12-11 23:52:34 +0000
committerPete Batard <pete@akeo.ie>2013-12-30 21:58:07 +0000
commit8cb3cb34fb7dca5d7586c68a61f2761a2e103195 (patch)
tree6a244d89d3b7b8c4c4d2accb7822acb9450eb2ba /examples/fxload.c
parent8b46e1c088167eb86b1712765896e2f17d70d148 (diff)
downloadlibusb-8cb3cb34fb7dca5d7586c68a61f2761a2e103195.tar.gz
misc: revert all references to libusb/libusb.infomergeback
Diffstat (limited to 'examples/fxload.c')
-rw-r--r--examples/fxload.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/fxload.c b/examples/fxload.c
index 14226ca..9f0d554 100644
--- a/examples/fxload.c
+++ b/examples/fxload.c
@@ -40,7 +40,7 @@ static bool dosyslog = false;
#endif
#ifndef FXLOAD_VERSION
-#define FXLOAD_VERSION (__DATE__ " (libusbx)")
+#define FXLOAD_VERSION (__DATE__ " (libusb)")
#endif
#ifndef ARRAYSIZE
@@ -69,7 +69,7 @@ static int print_usage(int error_code) {
fprintf(stderr, " -i <path> -- Firmware to upload\n");
fprintf(stderr, " -t <type> -- Target type: an21, fx, fx2, fx2lp, fx3\n");
fprintf(stderr, " -d <vid:pid> -- Target device, as an USB VID:PID\n");
- fprintf(stderr, " -p <bus,addr> -- Target device, as a libusbx bus number and device address path\n");
+ fprintf(stderr, " -p <bus,addr> -- Target device, as a libusb bus number and device address path\n");
fprintf(stderr, " -v -- Increase verbosity\n");
fprintf(stderr, " -q -- Decrease verbosity (silent mode)\n");
fprintf(stderr, " -V -- Print program version\n");
@@ -165,7 +165,7 @@ int main(int argc, char*argv[])
}
}
/* open the device using libusbx */
status = libusb_init(NULL);
if (status < 0) {
logerror("libusb_init() failed: %s\n", libusb_error_name(status));
@@ -165,7 +165,7 @@ int main(int argc, char*argv[])
}
}
- /* open the device using libusbx */
+ /* open the device using libusb */
status = libusb_init(NULL);
if (status < 0) {